@@ -917,7 +917,7 @@ class WSGIServer(Layer):
         """Create a WSGI server instance and save it in self.server.
         """
         app = self.make_wsgi_app()
-        kwargs = {}
+        kwargs = {'clear_untrusted_proxy_headers': False}
         if self.host is not None:
             kwargs['host'] = self.host
         if self.port is not None:
@@ -935,7 +935,10 @@ class WSGIServer(Layer):
         """Close the server socket and clean up.
         """
         self.server.shutdown()
-        shutil.rmtree(self._wsgi_conf_dir)
+        try:
+            shutil.rmtree(self._wsgi_conf_dir)
+        except OSError:
+            pass
 
     def make_wsgi_app(self):
         self._wsgi_conf_dir = tempfile.mkdtemp()
